@@ -1,5 +1,3 @@
-/* $Xorg: XChgDCtl.c,v 1.4 2001/02/09 02:03:50 xorgcvs Exp $ */
-
 /************************************************************
 
 Copyright 1989, 1998  The Open Group
@@ -45,7 +43,6 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ********************************************************/
-/* $XFree86: xc/lib/Xi/XChgDCtl.c,v 3.3 2001/12/14 19:55:03 dawes Exp $ */
 
 /***********************************************************************
  *
@@ -54,6 +51,10 @@ SOFTWARE.
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <X11/extensions/XI.h>
 #include <X11/extensions/XIproto.h>
 #include <X11/Xlibint.h>
@@ -62,11 +63,11 @@ SOFTWARE.
 #include "XIint.h"
 
 int
-XChangeDeviceControl(dpy, dev, control, d)
-    register Display *dpy;
-    XDevice *dev;
-    int control;
-    XDeviceControl *d;
+XChangeDeviceControl(
+    register Display	*dpy,
+    XDevice		*dev,
+    int			 control,
+    XDeviceControl	*d)
 {
     int length;
     xChangeDeviceControlReq *req;
